@@ -5,34 +5,31 @@
 
     LaTeX builder.
 
-    :copyright: Copyright 2007-2017 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
 import os
-import warnings
 from os import path
 
+from docutils import nodes
+from docutils.frontend import OptionParser
+from docutils.io import FileOutput
 from six import text_type
 
-from docutils import nodes
-from docutils.io import FileOutput
-from docutils.utils import new_document
-from docutils.frontend import OptionParser
-
 from sphinx import package_dir, addnodes, highlighting
-from sphinx.deprecation import RemovedInSphinx17Warning
-from sphinx.config import string_classes, ENUM
-from sphinx.errors import SphinxError, ConfigError
-from sphinx.locale import _
 from sphinx.builders import Builder
+from sphinx.config import string_classes, ENUM
 from sphinx.environment import NoUri
 from sphinx.environment.adapters.asset import ImageAdapter
+from sphinx.errors import SphinxError, ConfigError
+from sphinx.locale import _
 from sphinx.util import texescape, logging, status_iterator
-from sphinx.util.nodes import inline_all_toctrees
-from sphinx.util.fileutil import copy_asset_file
-from sphinx.util.osutil import SEP, make_filename
 from sphinx.util.console import bold, darkgreen  # type: ignore
+from sphinx.util.docutils import new_document
+from sphinx.util.fileutil import copy_asset_file
+from sphinx.util.nodes import inline_all_toctrees
+from sphinx.util.osutil import SEP, make_filename
 from sphinx.writers.latex import LaTeXWriter, LaTeXTranslator
 
 if False:
@@ -51,6 +48,12 @@ class LaTeXBuilder(Builder):
     """
     name = 'latex'
     format = 'latex'
+    epilog = 'The LaTeX files are in %(outdir)s.'
+    if os.name == 'posix':
+        epilog += ("\nRun 'make' in that directory to run these through "
+                   "(pdf)latex\n"
+                   "(use `make latexpdf' here to do that automatically).")
+
     supported_image_types = ['application/pdf', 'image/png', 'image/jpeg']
     supported_remote_images = False
     default_translator_class = LaTeXTranslator
@@ -260,26 +263,6 @@ class LaTeXBuilder(Builder):
 
 def validate_config_values(app):
     # type: (Sphinx) -> None
-    if app.config.latex_toplevel_sectioning not in (None, 'part', 'chapter', 'section'):
-        logger.warning('invalid latex_toplevel_sectioning, ignored: %s',
-                       app.config.latex_toplevel_sectioning)
-        app.config.latex_toplevel_sectioning = None  # type: ignore
-
-    if 'footer' in app.config.latex_elements:
-        if 'postamble' in app.config.latex_elements:
-            logger.warning("latex_elements['footer'] conflicts with "
-                           "latex_elements['postamble'], ignored.")
-        else:
-            warnings.warn("latex_elements['footer'] is deprecated. "
-                          "Use latex_elements['preamble'] instead.",
-                          RemovedInSphinx17Warning)
-            app.config.latex_elements['postamble'] = app.config.latex_elements['footer']
-
-    if app.config.latex_keep_old_macro_names:
-        warnings.warn("latex_keep_old_macro_names is deprecated. "
-                      "LaTeX markup since Sphinx 1.4.5 uses only prefixed macro names.",
-                      RemovedInSphinx17Warning)
-
     for document in app.config.latex_documents:
         try:
             text_type(document[2])
@@ -330,9 +313,9 @@ def setup(app):
                          None)
     app.add_config_value('latex_logo', None, None, string_classes)
     app.add_config_value('latex_appendices', [], None)
-    app.add_config_value('latex_keep_old_macro_names', False, None)
     app.add_config_value('latex_use_latex_multicolumn', False, None)
-    app.add_config_value('latex_toplevel_sectioning', None, None, [str])
+    app.add_config_value('latex_toplevel_sectioning', None, None,
+                         ENUM('part', 'chapter', 'section'))
     app.add_config_value('latex_domain_indices', True, None, [list])
     app.add_config_value('latex_show_urls', 'no', None)
     app.add_config_value('latex_show_pagerefs', False, None)
