@@ -60,7 +60,6 @@ import re
 import sys
 import warnings
 from types import ModuleType
-from typing import TYPE_CHECKING
 
 from docutils import nodes
 from docutils.parsers.rst import Directive, directives
@@ -78,9 +77,10 @@ from sphinx.ext.autodoc.directive import DocumenterBridge, Options
 from sphinx.ext.autodoc.importer import import_module
 from sphinx.pycode import ModuleAnalyzer, PycodeError
 from sphinx.util import import_object, rst, logging
-from sphinx.util.docutils import new_document
+from sphinx.util.docutils import NullReporter, new_document
 
-if TYPE_CHECKING:
+if False:
+    # For type annotation
     from typing import Any, Dict, List, Tuple, Type, Union  # NOQA
     from docutils.utils import Inliner  # NOQA
     from sphinx.application import Sphinx  # NOQA
@@ -90,6 +90,9 @@ if TYPE_CHECKING:
 logger = logging.getLogger(__name__)
 
 
+periods_re = re.compile('\.(?:\s+)')
+
+
 # -- autosummary_toc node ------------------------------------------------------
 
 class autosummary_toc(nodes.comment):
@@ -466,7 +469,7 @@ def extract_summary(doc, document):
             break
 
     # Try to find the "first sentence", which may span multiple lines
-    sentences = " ".join(doc).split('.')
+    sentences = periods_re.split(" ".join(doc))  # type: ignore
     if len(sentences) == 1:
         summary = sentences[0].strip()
     else:
@@ -475,6 +478,7 @@ def extract_summary(doc, document):
         while sentences:
             summary += sentences.pop(0) + '.'
             node = new_document('', document.settings)
+            node.reporter = NullReporter()
             state_machine.run([summary], node)
             if not node.traverse(nodes.system_message):
                 # considered as that splitting by period does not break inline markups
