@@ -8,7 +8,6 @@
     :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
-from __future__ import absolute_import
 from __future__ import print_function
 
 import contextlib
@@ -22,11 +21,11 @@ import sys
 import time
 from io import BytesIO, StringIO
 from os import path
-from typing import TYPE_CHECKING
 
 from six import PY2, PY3, text_type
 
-if TYPE_CHECKING:
+if False:
+    # For type annotation
     from typing import Any, Iterator, List, Tuple, Union  # NOQA
 
 # Errnos that we need.
